@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_prv
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -23,63 +25,37 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_2' => 'Tornatz a la pagina anteriora, e verificatz leis informacions qu’avètz fornidas. ',
 	'avis_connexion_ldap_echec_3' => 'Alternativament, utilizetz pas lo supòrt LDAP per importar d’utilizaires.',
 	'avis_deplacement_rubrique' => 'Atention! Aquela rubrica conten @contient_breves@ brèvas@scb@: se la desplaçatz, voudretz ben oscar aquela casa de confirmacion.',
-	'avis_destinataire_obligatoire' => 'Devètz indicar un destinatari avans de mandar aqueu messatge.',
 	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
-	'avis_erreur_version_archive' => '<b>Atencion! Lo fichier @archive@ correspònd a una autra version d’SPIP que la qu’avètz installada.</b> Anatz devèrs de dificultats grandassas: risca de destruccion de vòstra basa de donadas, disfoncionaments divèrs dau sit, etc. Validetz pas aquela demanda d’importacion.<p> Per mai d’informacions, vejatz
-<a href="@spipnet@">
-la documentacion d’SPIP</a>.', # MODIF
 	'avis_espace_interdit' => '<b>Espaci proïbit</b><p>SPIP es ja installat.',
 	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion a pas pogut legir lei noms dei basas de donadas installadas.',
 	'avis_lecture_noms_bases_2' => 'Siá ges de basa es disponibla, siá la foncion que permet d’entierar lei basas es estada desactivada per de rasons de seguretat (aquò’s lo cas en cò de mai d’un aubergador).',
 	'avis_lecture_noms_bases_3' => 'Dins la segonda alternativa, es probable qu’una basa que pòrta vòstre nom de login siá utilizabla:',
-	'avis_non_acces_message' => 'Podètz pas accedir a aqueu messatge.',
 	'avis_non_acces_page' => 'Podètz pas accedir a aquela pagina.',
 	'avis_operation_echec' => 'L’operacion s’es encalada.',
-	'avis_probleme_archive' => 'Problèma de lectura dau fichier @archive@',
 	'avis_suppression_base' => 'ATENCION, suprimir lei donadas es irreversible',
-	'avis_version_mysql' => 'Vòstra version de SQL (@version_mysql@) permet pas l’autoreparacion dei taulas de la basa.',
 
 	// B
 	'bouton_acces_ldap' => 'Apondre l’accès a LDAP >>',
 	'bouton_ajouter' => 'Apondre',
-	'bouton_ajouter_participant' => 'APONDRE UN PARTICIPANT:',
-	'bouton_annonce' => 'ANONCI',
-	'bouton_checkbox_envoi_message' => 'possibilitat de mandar un messatge',
-	'bouton_checkbox_indiquer_site' => 'indicar obligatoriament un sit web',
-	'bouton_checkbox_signature_unique_email' => 'ren qu’una signatura per adreiça e-mail',
-	'bouton_checkbox_signature_unique_site' => 'ren qu’una signatura per sit web',
 	'bouton_demande_publication' => 'Demandar la publicacion d’aquest article',
 	'bouton_desactive_tout' => 'Desactivar tot',
-	'bouton_effacer_index' => 'Escafar leis indèx',
 	'bouton_effacer_tout' => 'O escafar tot',
-	'bouton_envoi_message_02' => 'MANDAR UN MESSATGE',
 	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
 	'bouton_modifier' => 'Modificar',
-	'bouton_pense_bete' => 'MEMENTO (D’USATGE PERSONAU)',
-	'bouton_radio_activer_messagerie' => 'Activar la messatjariá intèrna',
-	'bouton_radio_activer_messagerie_interne' => 'Activar la messatjariá intèrna',
-	'bouton_radio_activer_petition' => 'Activar la peticion',
 	'bouton_radio_afficher' => 'Afichar',
 	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dins la tiera dei redactors connectats',
-	'bouton_radio_desactiver_messagerie' => 'Desactivar la messatjariá',
 	'bouton_radio_envoi_annonces_adresse' => 'Mandar leis anoncis a l’adreiça:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tiera dei novetats',
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Pas aparéisser dins la tiera dei redactors',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Pas mandar d’anoncis editoriaus',
-	'bouton_radio_pas_petition' => 'Ges de peticion',
-	'bouton_radio_petition_activee' => 'Peticion activada',
-	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',
 	'bouton_redirection' => 'TORNAR DIRIGIR',
 	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
 	'bouton_suivant' => 'Seguent',
 	'bouton_tenter_recuperation' => 'Assajar de reparar',
 	'bouton_test_proxy' => 'Assajar lo proxy',
 	'bouton_vider_cache' => 'Vujar l’escondedor',
-	'bouton_voir_message' => 'Veire aqueu messatge avans de lo validar',
 
 	// C
-	'cache_mode_compresse' => 'Lei fichiers de l’escondedor son registrats en mòde comprimit.',
-	'cache_mode_non_compresse' => 'Lei fichiers de l’escondedor son registrats en mòde non comprimit.',
 	'cache_modifiable_webmestre' => 'Lo webmèstre dau sit pòt modificar aquestei paramètres.',
 	'calendrier_synchro' => 'S’utilizatz un logiciau d’agenda compatible <b>iCal</b>, lo podètz sincronizar amb leis informacions d’aquest sit.',
 
@@ -107,7 +83,6 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'entree_login' => 'Lo vòstre login',
 	'entree_login_connexion_1' => 'Lo login de connexion',
 	'entree_login_connexion_2' => '(Correspònd de còps au vòstre login d’accès a l’FTP; de còps se laissa vuege)',
-	'entree_login_ldap' => 'Login LDAP iniciau',
 	'entree_mot_passe' => 'Vòstre mot de santa Clara',
 	'entree_mot_passe_1' => 'Mot de santa Clara per la connexion',
 	'entree_mot_passe_2' => '(Correspònd de còps a vòstre mot de santa Clara per l’FTP; de còps se laissa vuege)',
@@ -127,7 +102,7 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'ical_info2' => 'Per tenir mai d’informacions subre aquelei tecnicas, esitetz pas de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
 	'ical_info_calendrier' => 'I a dos calendiers a la vòstra disposicion. Lo primier es un plan dau sit qu’anóncia totei leis articles publicats. Lo segond conten leis anoncis editoriaus en mai de vòstrei darriers messatges privats: vos es reservat gràcias a una clau personala, que la podètz modificar en tot moment en renovant vòstre mot de santa Clara. ',
 	'ical_methode_http' => 'Telecargament',
-	'ical_methode_webcal' => 'Sincronizacion (webcal://)',
+	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
 	'ical_texte_js' => 'Leis articles publicats en aqueu sit se pòdon afichar aisat, dins totei lei sits vòstres, en fasent servir una linha javascript. ',
 	'ical_texte_prive' => 'Aqueu calendier, d’us estrictament personau, vos informa de l’activitat editoriala privada d’aqueu sit (òbras e rendètz-vos personaus, articles e brèvas prepausats...).',
 	'ical_texte_public' => 'Aqueu calendier vos permet de seguir l’activitat publica d’aqueu sit (articles e brèvas publicats).',
@@ -144,9 +119,7 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'icone_creer_auteur' => 'Crear un autor nòu e l’associar a aquel article',
 	'icone_creer_mot_cle' => 'Crear un mot clau nòu e lo liar a aquel article',
 	'icone_creer_rubrique_2' => 'Crear una rubrica nòva',
-	'icone_envoyer_message' => 'Mandar aqueu messatge',
 	'icone_modifier_article' => 'Modificar aquel article',
-	'icone_modifier_message' => 'Modificar aqueu messatge',
 	'icone_modifier_rubrique' => 'Modificar aquela rubrica',
 	'icone_retour' => 'Tornar',
 	'icone_retour_article' => 'Tornar a l’article',
@@ -156,10 +129,7 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'icone_valider_signature' => 'Validar aquela signatura',
 	'image_administrer_rubrique' => 'Podètz administrar aquela rubrica',
 	'info_1_article' => '1 article',
-	'info_1_site' => '1 sit',
 	'info_activer_cookie' => 'Podètz activar un <b>cookie de correspondéncia</b>; aquò vos permetrà de passar aisat dau sit public au sit privat.',
-	'info_admin_gere_rubriques' => 'Aquel administrator gerís lei rubricas seguentas:',
-	'info_admin_gere_toutes_rubriques' => 'Aquel administrator gerís <b>totei lei rubricas</b>.', # MODIF
 	'info_administrateur' => 'Administrator',
 	'info_administrateur_1' => 'Administrator',
 	'info_administrateur_2' => 'dau sit(<i>d’utilizar amb precaucion</i>)',
@@ -169,13 +139,10 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'info_administrer_rubrique' => 'Podètz administrar aquela rubrica',
 	'info_adresse' => 'a l’adreiça:',
 	'info_adresse_url' => 'Adreiça (URL) dau sit public',
-	'info_afficher_visites' => 'Afichar lei vesitas per:',
 	'info_aide_en_ligne' => 'Ajuda en linha SPIP',
 	'info_ajout_image' => 'Quand apondètz d’imatges coma estacaments jonchs a un article, SPIP pòt crear automaticament per vos de vinhetas (miniaturas) deis imatges inserits. Aquò permet per exemple de crear automaticament una galariá o un pòrtfòlio.',
-	'info_ajout_participant' => 'Lo participant seguent es apondut:',
 	'info_ajouter_rubrique' => 'Apondre una autra rubrica d’administrar:',
 	'info_annonce_nouveautes' => 'Anonci dei novetats',
-	'info_anterieur' => 'anteriora',
 	'info_article' => 'article',
 	'info_article_2' => 'articles',
 	'info_article_a_paraitre' => 'Leis articles pòstdatats per paréisser',
@@ -183,10 +150,8 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'info_articles_2' => 'Articles',
 	'info_articles_auteur' => 'Los articles d’aquel autor',
 	'info_articles_trouves' => 'Articles trobats',
-	'info_articles_trouves_dans_texte' => 'Articles trobats (dins lo tèxt)',
 	'info_attente_validation' => 'Vòstreis articles en espèra de validacion',
 	'info_aujourdhui' => 'uei:',
-	'info_auteur_message' => 'AUTOR DAU MESSATGE:',
 	'info_auteurs' => 'Leis autors',
 	'info_auteurs_par_tri' => 'autors@partri@',
 	'info_auteurs_trouves' => 'Autors trobats',
@@ -219,15 +184,12 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'info_date_publication_anterieure' => 'Data anteriora de publicacion:',
 	'info_date_referencement' => 'DATA DE REFERENCIAMENT D’AQUEU SIT:',
 	'info_derniere_etape' => 'Darriera estapa: <b>Es acabat!',
-	'info_derniers_articles_publies' => 'Vòstrei darriers articles publicats en linha',
-	'info_desactiver_messagerie_personnelle' => 'Podètz activar o desactivar vòstra messatjariá personala sus aqueu sit.',
 	'info_descriptif' => 'Descriptiu:',
 	'info_discussion_cours' => 'Discussions en cors',
 	'info_ecrire_article' => 'Avans de poder escriure d’articles, vos cau crear aumens una rubrica.',
 	'info_email_envoi' => 'Adreiça e-mail de mandadís (opcionau)',
 	'info_email_envoi_txt' => 'Indicatz aicí l’adreiça d’utilizar per enviar leis e-mails (a fauta d’aquò, s’utilizarà l’adreiça destinatari coma adreiça de mandadís):',
 	'info_email_webmestre' => 'Adreiça e-mail dau responsable dau sit (opcionau)', # MODIF
-	'info_entrer_code_alphabet' => 'Picatz lo còde de l’alfabet d’utilizar:',
 	'info_envoi_email_automatique' => 'Mandadís d’e-mails automatics',
 	'info_envoyer_maintenant' => 'Mandar ara',
 	'info_etape_suivante' => 'Passar a l’estapa seguenta',
@@ -237,27 +199,19 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'info_facilite_suivi_activite' => 'Per facilitar lo seguit de l’activitat editoriala dau sit, SPIP vos pòt fornir per e-mail, per exemple a una lista de corrier dei redactors, l’anonci dei demandas de publicacion e dei validacions d’articles.',
 	'info_fichiers_authent' => 'Fichiers d’autentificacion « .htpasswd »',
 	'info_forums_abo_invites' => 'Vòstre sit web porgís de forums per leis abonats; dins lo sit public lei vesitaires son convidats a se registrar.',
-	'info_gauche_admin_effacer' => '<b>A aquela pagina, ren que lei responsables dau sit i pòdon accedir.</b><p> Permet de trobar lei diferentei foncions de mantenença tecnica. D’unei que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
 	'info_gauche_admin_tech' => '<b>A aquela pagina, ren que lei responsables dau sit i pòdon accedir.</b><p> Permet de trobar lei diferentei foncions de mantenença tecnica. D’unei que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
 	'info_gauche_admin_vider' => '<b>A aquela pagina, ren que lei responsables dau sit i pòdon accedir.</b><p> Permet de trobar lei diferentei foncions de mantenença tecnica. D’unei que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
 	'info_gauche_auteurs' => 'Trobaretz aicí totei leis autors dau sit. La color deis icònas n’indica l’estatut (administrator = verd; redactor = jaune).',
 	'info_gauche_auteurs_exterieurs' => 'Leis autors exteriors, sens accès au sit, son indicats per una icòna blava; leis autors escafats per un bordilhier.', # MODIF
 	'info_gauche_messagerie' => 'La messatjariá vos permet d’escambiar de messatges entre redactors, de servar de mementos (per vòstre usatge personau) o d’afichar d’anoncis sus la pagina d’acuelh de l’espaci privat (se siatz administrator/tritz).',
-	'info_gauche_numero_auteur' => 'AUTOR NUMÈRO',
 	'info_gauche_statistiques_referers' => 'Aquela pagina presenta la lista dei <i>referidors</i>, valent a dire dei sits que contenon de liames menant vèrs vòstre sit pròpri, mai unicament per ièr e uei: aquela lista s’actualiza cada 24 oras.',
 	'info_gauche_visiteurs_enregistres' => 'Trobaretz aquí lei vesitaires registrats
  dins l’espaci public dau sit (forums amb abonament).',
 	'info_generation_miniatures_images' => 'Congreacion de miniaturas deis imatges',
-	'info_gerer_trad' => 'Gerir lei liames de revirada?',
 	'info_hebergeur_desactiver_envoi_email' => 'D’uneis aubergadors desactivan lo mandadís automatic
  d’e-mails dempuei sei servidors. En aqueu cas, lei foncionalitats seguentas
  d’SPIP foncionaràn pas.',
 	'info_hier' => 'ièr:',
-	'info_historique_activer' => 'Activar lo seguiment dei revisions',
-	'info_historique_affiche' => 'Afichar aquela version',
-	'info_historique_comparaison' => 'comparason',
-	'info_historique_desactiver' => 'Desactivar lo seguiment dei revisions',
-	'info_historique_texte' => 'Lo seguiment dei revisions permet de servar un istoric de totei lei modificacions que s’es portat au contengut d’un article, e d’afichar lei diferéncias entre lei versions successivas.',
 	'info_identification_publique' => 'Vòstra identitat publica...',
 	'info_image_process' => 'Vougatz seleccionar lo melhor metòde de fabricacion dei vinhetas en clicant sus l’imatge correspondent.',
 	'info_image_process2' => '<b>N.B.</b> <i>Se ges d’imatge apareis, aladonc lo servidor qu’aubèrga vòstre sit l’an pas configurat per utilizar d’aisinas talas. Se desiratz d’utilizar aquelei foncions, contactatz lo responsable tecnic e demandatz leis extensions «GD» o «Imagick».</i>', # MODIF
@@ -275,8 +229,6 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'info_login_trop_court' => 'Login tròp cort.',
 	'info_maximum' => 'maximum:',
 	'info_meme_rubrique' => 'Dins la meteissa rubrica',
-	'info_message' => 'Messatge dau',
-	'info_message_efface' => 'MESSATGE ESCAFAT',
 	'info_message_en_redaction' => 'Vòstrei messatges en cors de redaccion',
 	'info_message_technique' => 'Messatge tecnic:',
 	'info_messagerie_interne' => 'Messatjariá intèrna',
@@ -289,20 +241,15 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'info_modifier_rubrique' => 'Modificar la rubrica:',
 	'info_modifier_titre' => 'Modificar: @titre@',
 	'info_mon_site_spip' => 'Mon sit SPIP',
-	'info_mot_sans_groupe' => '(Mots fòra grop...)',
-	'info_moteur_recherche' => 'Cercador integrat',
 	'info_moyenne' => 'mejana:',
-	'info_multi_articles' => 'Activar lo menut de lenga per leis articles?',
 	'info_multi_cet_article' => 'Lenga d’aquest article:',
 	'info_multi_langues_choisies' => 'Vougatz seleccionar çai sota lei lengas que son a posita dei redactors de vòstre sit.
   Lei lengas ja emplegadas dins vòstre sit (afichadas d’en primier) se pòdon pas desactivar.',
-	'info_multi_rubriques' => 'Activar lo menut de lenga per lei rubricas?',
 	'info_multi_secteurs' => '... ren que per lei rubricas a la raiç dau sit?',
 	'info_nom' => 'Nom',
 	'info_nom_destinataire' => 'Nom dau destinatari',
 	'info_nom_site' => 'Nom dau vòstre sit',
 	'info_nombre_articles' => '@nb_articles@ articles,',
-	'info_nombre_partcipants' => 'PARTICIPANTS A LA DISCUSSION:',
 	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
 	'info_nombre_sites' => '@nb_sites@ sits,',
 	'info_non_deplacer' => 'De pas desplaçar...',
@@ -312,36 +259,26 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
 	'info_non_modifiable' => 'se pòt pas modificar',
 	'info_non_suppression_mot_cle' => 'vòli pas suprimir aqueu mot clau.',
 	'info_notes' => 'Nòtas',
-	'info_nouveaux_message' => 'Messatges nòus',
 	'info_nouvel_article' => 'Article nòu',
 	'info_nouvelle_traduction' => 'Revirada nòva:',
 	'info_numero_article' => 'ARTICLE NUMÈRO:',
 	'info_obligatoire_02' => '[Obligatòri]', # MODIF
 	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion dei vesitaires dau sit public',
-	'info_option_faire_suivre' => 'Faire seguir lei messatges dei forums ais autors deis articles',
 	'info_option_ne_pas_accepter_visiteurs' => 'Refusar l’inscripcion de vesitaires',
 	'info_options_avancees' => 'OPCIONS AVANÇADAS',
-	'info_ortho_activer' => 'Activar lo verificador d’ortografia',
-	'info_ortho_desactiver' => 'Desactivar lo verificador d’ortografia',
 	'info_ou' => 'o... ',
 	'info_page_interdite' => 'Pagina proïbida',
 	'info_par_nombre_article' => '(per nombre d’articles)',
 	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
 	'info_passes_identiques' => 'Lei dos mots de santa Clara son pas identics.',
-	'info_pense_bete_ancien' => 'Vòstrei mementos ancians', # MODIF
 	'info_plus_cinq_car' => 'mai de 5 caractèrs',
 	'info_plus_cinq_car_2' => '(mai de 5 caractèrs)',
 	'info_plus_trois_car' => '(mai de 3 caractèrs)',
 	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
-	'info_popularite_4' => 'popularitat: @popularite@; vesitas: @visites@',
 	'info_post_scriptum' => 'Post-scriptum',
 	'info_post_scriptum_2' => 'Post-scriptum:',
 	'info_pour' => 'per',
-	'info_preview_admin' => 'Solament leis administrators pòdon previsualizar lo sit',
-	'info_preview_comite' => 'Totei lei redactors pòdon previsualizar lo sit',
-	'info_preview_desactive' => 'La previsualizacion es dau tot desactivada',
-	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avián publicat totei leis articles e brèvas (que tenon aumens l’estatut "prepausat"). La cau dobrir, aquela possibilitat, ren qu’ais administrators, a totei lei redactors, o en degun?',
-	'info_principaux_correspondants' => 'Vòstrei correspondents principaus',
+	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avián publicat totei leis articles e brèvas (que tenon aumens l’estatut "prepausat"). La cau dobrir, aquela possibilitat, ren qu’ais administrators, a totei lei redactors, o en degun?', # MODIF
 	'info_procedez_par_etape' => 'procedissètz estapa per estapa',
 	'info_procedure_maj_version' => 'Cau lançar la procedura d’actualizacion per adaptar
  la basa de donadas a la version novèla d’SPIP.',
@@ -356,12 +293,9 @@ L’administrator dau sistèma o de la ret vos deu poder fornir
  que li baila un còde d’accès au sit privat.
 D’uneis aubergadors autorizan pas lo mandadís d’e-mails dempuei sei servidors: en aqueu cas, l’inscripcion automatica es
  impossibla.', # MODIF
-	'info_question_utilisation_moteur_recherche' => 'Desiratz d’utilizar lo cercador integrat a SPIP? (lo desactivar abriva lo foncionament dau sistèma.)',
 	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
 	'info_racine_site' => 'Raiç dau sit',
 	'info_recharger_page' => 'Vougatz tornar cargar aquela pagina dins un momenton.',
-	'info_recherche_auteur_a_affiner' => 'Tròp de resultats per "@cherche_auteur@"; vougatz afinar la cèrca.',
-	'info_recherche_auteur_ok' => 'Mai d’un redactor trobat per "@cherche_auteur@":',
 	'info_recherche_auteur_zero' => '<b>Ges de resultat trobat per "@cherche_auteur@".',
 	'info_recommencer' => 'Vougatz tornar començar.',
 	'info_redacteur_1' => 'Redactor',
@@ -378,7 +312,6 @@ D’uneis aubergadors autorizan pas lo mandadís d’e-mails dempuei sei servido
 	'info_rubriques' => 'Rubricas',
 	'info_rubriques_02' => 'rubricas',
 	'info_rubriques_trouvees' => 'Rubricas trobadas',
-	'info_rubriques_trouvees_dans_texte' => 'Rubricas trobadas (dins lo tèxt)',
 	'info_sans_titre' => 'Sensa títol',
 	'info_selection_chemin_acces' => '<b>Seleccionatz</b> çai sota lo camin d’accès dins l’annuari:',
 	'info_signatures' => 'signaturas',
@@ -391,13 +324,11 @@ D’uneis aubergadors autorizan pas lo mandadís d’e-mails dempuei sei servido
 	'info_sites_lies_mot' => 'Lei sits referenciats ligats a aqueu mot clau',
 	'info_sites_proxy' => 'Utilizar un proxy',
 	'info_sites_trouves' => 'Sits trobats',
-	'info_sites_trouves_dans_texte' => 'Sits trobats (dins lo tèxt)',
 	'info_sous_titre' => 'Sostítol:',
 	'info_statut_administrateur' => 'Administrator',
 	'info_statut_auteur' => 'Estatut d’aquel autor:', # MODIF
 	'info_statut_auteur_a_confirmer' => 'Inscripcion de confirmar',
 	'info_statut_auteur_autre' => 'Autre estatut :',
-	'info_statut_efface' => 'Escafat',
 	'info_statut_redacteur' => 'Redactor',
 	'info_statut_utilisateurs_1' => 'Estatut predefinit deis utilizaires importats',
 	'info_statut_utilisateurs_2' => 'Chausissètz l’estatut d’atribuir ai personas presentas dins l’annuari LDAP quora se connèctan per lo primier còp. Poiretz puei modificar aquel estatut per cada autor un cas per un.',
@@ -415,7 +346,6 @@ D’uneis aubergadors autorizan pas lo mandadís d’e-mails dempuei sei servido
 	'info_tous_articles_en_redaction' => 'Totei leis articles en cors de redaccion',
 	'info_tous_articles_presents' => 'Totei leis articles publicats dins aquela rubrica',
 	'info_tous_les' => 'totei lei:',
-	'info_tous_redacteurs' => 'Anoncis a totei lei redactors ',
 	'info_tout_site' => 'Tot lo sit',
 	'info_tout_site2' => 'An pas revirat l’article dins aquela lenga.',
 	'info_tout_site3' => 'An revirat l’article dins aquela lenga, mai an portat puei de modificacions a l’article de referéncia. Cau actualizar la revirada.',
@@ -430,7 +360,6 @@ una color indica lor estat:',
 	'info_une_rubrique' => 'una rubrica, ',
 	'info_une_rubrique_02' => '1 rubrica',
 	'info_url' => 'URL:',
-	'info_url_site' => 'URL DAU SIT:',
 	'info_urlref' => 'Liame ipertèxt:',
 	'info_utilisation_spip' => 'Ara podètz començar d’utilizar lo sistèma de publicacion assistida...',
 	'info_visites_par_mois' => 'Afichatge per mes:',
@@ -447,15 +376,12 @@ una color indica lor estat:',
 	'item_activer_messages_avertissement' => 'Activar lei messatges d’avertiment',
 	'item_administrateur_2' => 'administrator',
 	'item_afficher_calendrier' => 'Afichar dins lo calendier',
-	'item_autoriser_documents_joints' => 'Autorizar que se jonga de documents ais articles',
-	'item_autoriser_documents_joints_rubriques' => 'Autorizar lei documents dins lei rubricas',
 	'item_choix_administrateurs' => 'leis administrators',
 	'item_choix_generation_miniature' => 'Congrear automaticament lei miniaturas deis imatges.',
 	'item_choix_non_generation_miniature' => 'Congrear ges de miniaturas deis imatges.',
 	'item_choix_redacteurs' => 'lei redactors',
 	'item_choix_visiteurs' => 'lei vesitaires dau sit public',
 	'item_creer_fichiers_authent' => 'Crear de fichiers .htpasswd',
-	'item_limiter_recherche' => 'Limitar la cèrca ais informacions contengudas dins vòstre sit',
 	'item_login' => 'Login',
 	'item_mots_cles_association_articles' => 'ais articles',
 	'item_mots_cles_association_rubriques' => 'ai rubricas',
@@ -464,34 +390,24 @@ una color indica lor estat:',
 	'item_non_accepter_inscriptions' => 'Pas acceptar leis inscripcions',
 	'item_non_activer_messages_avertissement' => 'Ges de messatge d’avertiment',
 	'item_non_afficher_calendrier' => 'De pas afichar dins lo calendier',
-	'item_non_autoriser_documents_joints' => 'Pas autorizar lei documents dins leis articles',
-	'item_non_autoriser_documents_joints_rubriques' => 'Pas autorizar lei documents dins lei rubricas',
 	'item_non_creer_fichiers_authent' => 'Pas crear aquelei fichiers',
-	'item_non_gerer_statistiques' => 'Pas gerir leis estadisticas',
-	'item_non_limiter_recherche' => 'Alargar la cèrca au contengut dei sits referenciats',
 	'item_non_publier_articles' => 'Pas publicar leis articles avans la data de publicacion prevista.',
-	'item_non_utiliser_moteur_recherche' => 'Pas utilizar lo motor',
 	'item_nouvel_auteur' => 'Autor nòu',
 	'item_nouvelle_rubrique' => 'Rubrica nòva',
 	'item_oui' => 'Òc',
 	'item_publier_articles' => 'Publicar leis articles, quina que siá sa data de publicacion',
 	'item_reponse_article' => 'Respònsa a l’article',
-	'item_utiliser_moteur_recherche' => 'Utilizar lo cercador',
 	'item_visiteur' => 'vesitaire',
 
 	// J
 	'jour_non_connu_nc' => 'n.c.',
 
 	// L
-	'lien_ajout_destinataire' => 'Apondre aqueu destinatari',
 	'lien_ajouter_auteur' => 'Apondre aquel autor',
-	'lien_ajouter_participant' => 'Apondre un participant',
 	'lien_email' => 'e-mail',
 	'lien_nom_site' => 'NOM DAU SIT:',
 	'lien_retirer_auteur' => 'Levar l’autor',
-	'lien_retrait_particpant' => 'Levar aqueu participant',
 	'lien_site' => 'sit',
-	'lien_supprimer_rubrique' => 'suprimir aquela rubrica',
 	'lien_tout_deplier' => 'Desplegar tot',
 	'lien_tout_replier' => 'Tornar plegar',
 	'lien_trier_nom' => 'Triar per nom',
@@ -526,6 +442,7 @@ una color indica lor estat:',
 
 	// R
 	'repertoire_plugins' => 'Repertòri :',
+	'required' => '[Obligatòri]', # MODIF
 
 	// S
 	'statut_admin_restreint' => '(admin. restrench)', # MODIF
@@ -549,14 +466,10 @@ una color indica lor estat:',
 	'texte_article_virtuel_reference' => '<b>Article virtuau:</b> article referenciat dins vòstre sit SPIP, mai redirigit vèrs una autra URL. Per suprimir la redireccion, escafatz l’URL çai subre.',
 	'texte_aucun_resultat_auteur' => 'Ges de resultat per "@cherche_auteur@"',
 	'texte_auteur_messagerie' => 'Aquest sit vos pòt indicar de contunha la tiera dei redactors connectats, çò que vos permet d’escambiar de messatges en dirècte. Podètz decidir de pas aparéisser dins aquela lista (siatz "invisible/a" per leis autreis utilizaires).',
-	'texte_auteur_messagerie_1' => 'Aqueu sit permet d’escambiar de messatges e de constituir de forums de discussion privats entre lei participants dau sit. Podètz decidir de pas participar a aqueleis escambis.',
 	'texte_auteurs' => 'LEIS AUTORS',
 	'texte_choix_base_1' => 'Chausissètz vòstra basa:',
 	'texte_choix_base_2' => 'Lo servidor SQL conten mai d’una basa de donadas.',
 	'texte_choix_base_3' => '<b>Chausissètz</b> çai sota la que vòstre aubergador vos a atribuida:',
-	'texte_commande_vider_tables_indexation' => 'Utilizatz aquela comanda per vujar lei taulas d’indexacion utilizadas per lo cercador integrat a SPIP. Aquò permetrà
- de ganhar d’espaci disc.',
-	'texte_compresse_ou_non' => '(Aquest se pòt comprimir o non)',
 	'texte_compte_element' => '@count@ element',
 	'texte_compte_elements' => '@count@ elements',
 	'texte_connexion_mysql' => 'Consultatz leis informacions que vòstre aubergador fornís: i devètz trobar, se vòstre aubergador supòrta SQL, lei còdes de connexion au servidor SQL.', # MODIF
@@ -572,10 +485,8 @@ una color indica lor estat:',
 	'texte_date_publication_anterieure' => 'DATA DE PUBLICACION ANTERIORA :',
 	'texte_date_publication_anterieure_nonaffichee' => 'Afichar ges de data de publicacion anteriora.',
 	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA :',
-	'texte_descriptif_petition' => 'Descriptiu de la peticion',
 	'texte_descriptif_rapide' => 'Descriptiu rapid',
 	'texte_effacer_base' => 'Escafar la basa de donadas SPIP',
-	'texte_effacer_donnees_indexation' => 'Escafar lei donadas d’indexacion',
 	'texte_en_cours_validation' => 'Se prepausa de publicar leis articles e brèvas çai sota. Esitetz pas de donar vòstre vejaire gràcias ai forums que i son estacats.', # MODIF
 	'texte_enrichir_mise_a_jour' => 'Podètz enriquir la compaginacion de vòstre tèxt en utilizant d’"acorchas tipograficas".',
 	'texte_fichier_authent' => '<b>Deu crear, SPIP, de fichiers especiaus  <tt>.htpasswd</tt>
@@ -594,30 +505,17 @@ una color indica lor estat:',
  En aqueu cas, cau cambiar lo reglatge predefinit per fin d’utilizar
  un jòc de caractèrs apropriat. Oblidetz pas tanpauc d’adaptar
  lo sit public en consequéncia (balisa <tt>#CHARSET</tt>).',
-	'texte_jeu_caractere_2' => 'Aquest reglatge a ges d’efiech retroactiu. Adoncas
- lei tèxts ja sasits se pòdon afichar
- d’un biais incorrècte après que s’aga modificat lo reglatge. De tot biais
- poiretz tornar sensa damatge au reglatge precedent.',
 	'texte_jeu_caractere_3' => 'Vòstre sit es per ara installat amb lo jòc de caractèrs :',
-	'texte_lien_hypertexte' => '(Se vòstre messatge se referís a un article publicat sus lo web, o a una pagina fornissent mai d’informacions, vougatz indicar çai sota lo títol de la pagina e son adreiça URL.)',
 	'texte_login_ldap_1' => '(Laissar vuege per un accès anonim, o picar lo camin complet, per exemple «<tt>uid=fabre, ou=usanciers, dc=mon-domeni, dc=com</tt>».)',
 	'texte_login_precaution' => 'Atencion! Aquò’s lo login amb lo quau siatz ara connectat/ada. 
  Utilizatz aquest formulari amb precaucion...',
-	'texte_message_edit' => 'Atencion: aquest messatge, cada redactor lo pòt veire, e cada administrator dau sit lo pòt modificar. Utilizatz leis anoncis ren que per expausar d’eveniments importants de la vida dau sit.',
 	'texte_mise_a_niveau_base_1' => 'Venètz d’actualizar lei fichiers SPIP.
  Ara cau metre a nivèu la basa de donadas
  dau sit.',
 	'texte_modifier_article' => 'Modificar l’article:',
-	'texte_moteur_recherche_active' => '<b>Lo cercador es activat.</b> Utilizatz aquesta commanda
-  se volètz tornar indexar la basa rapidament (après restauracion
-  d’una sauvagarda per exemple). Notatz que lei documents modificats d’un 
-  biais normau (a partir de l’interfàcia SPIP) se tornan indexar
-  automaticament: donc aquesta comanda es utila ren que d’un biais excepcionau.',
-	'texte_moteur_recherche_non_active' => 'Lo cercador es pas activat.',
 	'texte_multilinguisme' => 'Se desiratz de gerir d’articles en mai d’una lenga, amb una navigacion complèxa, podètz apondre un menut per chausir la lenga deis articles e/o dei rubricas, en foncion de l’organizacion de vòstre sit.', # MODIF
 	'texte_multilinguisme_trad' => 'Podètz tanben activar un sistèma de gestion dei liames entre lei diferentei reviradas d’un article.', # MODIF
 	'texte_non_compresse' => '<i>non comprimit</i> (per amòr que vòstre servidor supòrta pas aquela foncionalitat)',
-	'texte_nouveau_message' => 'Messatge nòu',
 	'texte_nouvelle_version_spip_1' => 'Avètz installada una version novèla d’SPIP.',
 	'texte_nouvelle_version_spip_2' => 'Aquesta version novèla demanda una actualizacion mai completa que de costuma. Se siatz webmèstre/webmèstra dau sit, vougatz escafar lo fichier <tt>inc_connect.php3</tt> dau repertòri <tt>ecrire</tt> e tornar prene l’installacion per fin d’actualizar vòstrei paramètres de connexion a la basa de donadas.<p> (NB: s’avètz demembrat vòstrei paramètres de connexion, espepissatz lo fichier  <tt>inc_connect.php3</tt> avans de lo suprimir...)</p>', # MODIF
 	'texte_operation_echec' => 'Tornatz a la pagina precedenta, chausissètz una autra basa o creatz-ne’n una novèla. Verificatz leis informacions que vòstre aubergador a fornidas.',
@@ -636,7 +534,6 @@ una color indica lor estat:',
 	'texte_rappel_selection_champs' => '[Oblidetz pas de seleccionar aqueu camp correctament.]',
 	'texte_recalcul_page' => 'Se volètz
 tornar calcular ren qu’una pagina, passatz puslèu per l’espaci public e utilizatz lo  boton "tornar calcular".',
-	'texte_recapitiule_liste_documents' => 'Aquesta pagina recapitula la tiera dei documents qu’avètz plaçats dins lei rubricas. Per modificar leis informacions de cada document, seguissètz lo liame vèrs la pagina de sa rubrica.',
 	'texte_recuperer_base' => 'Reparar la basa de donadas',
 	'texte_reference_mais_redirige' => 'article referenciat dins vòstre sit SPIP, mai redirigit vèrs una autra URL.',
 	'texte_requetes_echouent' => '<b>Quora d’unei requistas SQL s’encalan
@@ -664,7 +561,6 @@ dins l’escondedor SPIP. Aquò permet per exemple de forçar un calcul nòu de
 s’avètz bravament modificat lo grafisme o l’estructura dau sit.',
 	'texte_sur_titre' => 'Subretítol',
 	'texte_table_ok' => ': aquesta taula es condrecha.',
-	'texte_tables_indexation_vides' => 'Lei taulas d’indexacion dau motor son vuejas.',
 	'texte_tentative_recuperation' => 'Assai de reparacion',
 	'texte_tenter_reparation' => 'Assajar de reparar la basa de donadas',
 	'texte_test_proxy' => 'Per assajar aqueu proxy, indicatz aicí l’adreiça d’un sit web
@@ -679,26 +575,8 @@ s’avètz bravament modificat lo grafisme o l’estructura dau sit.',
   Aquela opcion es desactivada de maniera predefinida
   per fin d’evitar d’afichar de messatges d’avertiment
   intempestius.',
-	'texte_trop_resultats_auteurs' => 'Tròp de resultats per "@cherche_auteur@" ; vougatz afinar la cèrca.',
-	'texte_unpack' => 'telecargament de la darriera version',
-	'texte_utilisation_moteur_syndiques' => 'Quora utilizatz lo cercador integrat 
-    a SPIP, podètz far lei cèrcas subre lei sits e
-    articles sindicats de dos biais
-    diferents. <br /><img src=\'puce.gif\' /> Lo mai
-    simple consistís a cercar ren que dins lei
-    títols e descriptius deis articles. <br /><img src=\'puce.gif\' />
-    Lo segond biais, ben mai potent, permet
-    a SPIP de cercar tanben dins lo tèxt dei
-    sits referenciats. 
-   Se referenciatz un sit, alora SPIP farà la
-    cèrca dins lo tèxt dau sit meteis.', # MODIF
-	'texte_utilisation_moteur_syndiques_2' => 'Aqueu metòde obliga SPIP de vesitar
-    regularament lei sits referenciats,
-    aquò pòt alentir un pauc lo vòstre
-    sit.',
 	'texte_vide' => 'vuege',
 	'texte_vider_cache' => 'Vujar l’escondedor',
-	'titre_admin_effacer' => 'Mantenença tecnica',
 	'titre_admin_tech' => 'Mantenença tecnica',
 	'titre_admin_vider' => 'Mantenença tecnica',
 	'titre_cadre_afficher_article' => 'Afichar leis articles',
@@ -718,40 +596,23 @@ s’avètz bravament modificat lo grafisme o l’estructura dau sit.',
 	'titre_naviguer_dans_le_site' => 'Navigar per lo sit...',
 	'titre_nouvelle_rubrique' => 'Rubrica novèla',
 	'titre_numero_rubrique' => 'RUBRICA NUMÈRO:',
-	'titre_page_admin_effacer' => 'Mantenença tecnica: escafar la basa',
 	'titre_page_articles_edit' => 'Modificar: @titre@',
 	'titre_page_articles_page' => 'Leis articles',
 	'titre_page_articles_tous' => 'Tot lo sit',
-	'titre_page_auteurs' => 'Vesitaires',
 	'titre_page_calendrier' => 'Calendier @nom_mois@ de @annee@',
 	'titre_page_config_contenu' => 'Configuracion dau sit',
-	'titre_page_config_fonctions' => 'Configuracion dau sit',
-	'titre_page_configuration' => 'Configuracion dau sit',
-	'titre_page_controle_petition' => 'Seguit dei peticions',
 	'titre_page_delete_all' => 'supression totala e irreversibla',
-	'titre_page_documents_liste' => 'Lei documents dei rubricas',
-	'titre_page_index' => 'Vòstre espaci privat',
-	'titre_page_message_edit' => 'Redigir un messatge',
-	'titre_page_messagerie' => 'Vòstra messatjariá',
 	'titre_page_recherche' => 'Resultats de la cèrca @recherche@',
 	'titre_page_statistiques_referers' => 'Estadisticas (liames intrants)',
 	'titre_page_upgrade' => 'Mesa a nivèu d’SPIP',
 	'titre_publication_articles_post_dates' => 'Publicacion deis articles pòstdatats',
-	'titre_referencer_site' => 'Referenciar lo sit:',
-	'titre_rendez_vous' => 'RENDÈTZ-VOS:',
 	'titre_reparation' => 'Reparacion',
 	'titre_suivi_petition' => 'Seguit dei peticions',
-	'trad_article_inexistant' => 'I a ges d’article que pòrte aqueu numèro.',
 	'trad_article_traduction' => 'Totei lei versions d’aquel article:',
-	'trad_deja_traduit' => 'Aquel article ja es una revirada de l’article present.',
 	'trad_delier' => 'Cessar de liar aquest article a sei reviradas ', # MODIF
 	'trad_lier' => 'Aquest article es una revirada de l’article numèro:',
 	'trad_new' => 'Escriure una revirada novèla d’aquest article', # MODIF
 
-	// U
-	'utf8_convert_termine' => 'Es acabat !',
-	'utf8_convertir_votre_site' => 'Convertir vòstre sit en utf-8',
-
 	// V
 	'version' => 'Version :'
 );
