@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -31,7 +33,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'annuler' => 'Annuler',
 	'antispam_champ_vide' => 'Veuillez laisser ce champ vide :',
 	'articles_recents' => 'Articles les plus récents',
-	'avis_1_erreur_saisie' => 'Il y a 1 erreur dans dans votre saisie, veuillez vérifier les informations.',
+	'avis_1_erreur_saisie' => 'Il y a 1 erreur dans votre saisie, veuillez vérifier les informations.',
 	'avis_archive_incorrect' => 'le fichier archive n’est pas un fichier SPIP',
 	'avis_archive_invalide' => 'le fichier archive n’est pas valide',
 	'avis_attention' => 'ATTENTION !',
@@ -534,7 +536,7 @@ le site "@nom_site_spip@" (@adresse_login@) :',
 	'login_retour_public' => 'Retour au site public',
 	'login_retour_site' => 'Retour au site public',
 	'login_retoursitepublic' => 'retour au site public',
-	'login_sans_cookiie' => 'Identification sans cookie',
+	'login_sans_cookie' => 'Identification sans cookie',
 	'login_securise' => 'Login sécurisé',
 	'login_sinscrire' => 's’inscrire',
 	'login_test_navigateur' => 'test navigateur/reconnexion',
@@ -598,7 +600,7 @@ et vous reconnecter au site.
 	'pass_nouveau_pass' => 'Nouveau mot de passe',
 	'pass_ok' => 'OK',
 	'pass_oubli_mot' => 'Oubli du mot de passe',
-	'pass_procedure_changer' => 'Pour changer votre mot de passe, nous devons d’abord vérifier votre identité. Pour cela indiquez-nous l’adresse email associée à votre compte.',
+	'pass_procedure_changer' => 'Pour modifier votre mot de passe, merci d’indiquer l’adresse email associée à votre compte.',
 	'pass_quitter_fenetre' => 'Quitter cette fenêtre',
 	'pass_rappel_login' => 'Rappel : votre identifiant (login) est « @login@ ».',
 	'pass_recevoir_mail' => 'Vous allez recevoir un email vous indiquant comment retrouver votre accès au site.',
