@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,21 +13,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Plejbonigoj kaj densigoj',
 	'info_question_activer_compactage_css' => 'CSS',
 	'info_question_activer_compactage_js' => 'Skriptoj',
-	'info_question_activer_compresseur' => 'HTML',
 	'item_compresseur_closure' => 'Uzi Google Closure Compiler [eksperimenta]',
 	'item_compresseur_css' => 'Aktivigi la densigon de la stilfolio (CSS)',
-	'item_compresseur_html' => 'Aktivigi densigon de HTML',
 	'item_compresseur_js' => 'Aktivigi la densigon de la skriptoj (ĝavoskripto)',
 
 	// T
 	'texte_compacter_avertissement' => 'Atentu ne ebligi tiujn opciojn dum disvolviĝo de via retejo : la densigaj elementoj perdas ĉian legeblecon.',
 	'texte_compacter_script_css' => 'SPIP povas densigi ĝavoskriptaj skriptoj kaj CSS stilfolioj, por registri ilin en statikaj dosieroj. Tio plirapidigas la afiŝon de la retejo.',
-	'texte_compresseur_page' => 'SPIP povas aŭtomate densigi ĉiun paĝon kiun ĝi sendas al
-retej-vizitantoj. Tiu agordo permesas optimumi la bendlarĝo (la
-retejo estas pli rapida malantaŭ ligo kun malforta kapacito de traigivo), sed
-postulas pli da potenco al la servilo.',
-	'titre_compacter_script_css' => 'Densigo de skriptojn kaj CSS',
-	'titre_compresser_flux_http' => 'Densigo de la HTTP-fluo'
+	'titre_compacter_script_css' => 'Densigo de skriptojn kaj CSS'
 );
 
 ?>
