@@ -3,7 +3,9 @@
 // extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) return;
+if (!defined('_ECRIRE_INC_VERSION')) {
+	return;
+}
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -11,18 +13,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_compresseur_titre' => 'Optimização e compressão',
 	'info_question_activer_compactage_css' => 'CSS',
 	'info_question_activer_compactage_js' => 'Scripts',
-	'info_question_activer_compresseur' => 'HTML',
 	'item_compresseur_closure' => 'Utilizar Google Closure Compiler [experimental]',
 	'item_compresseur_css' => 'Activar a compressão das folhas de estilo (CSS)',
-	'item_compresseur_html' => 'Activar a compressão de HTML',
 	'item_compresseur_js' => 'Activar a compressão de scripts (javascript)',
 
 	// T
 	'texte_compacter_avertissement' => 'Tenha cuidado para não activar estas opções durante o desenvolvimento do seu sítio, pois os elementos comprimidos são difíceis de ler e depurar.',
 	'texte_compacter_script_css' => 'SPIP pode compactar ficheiros Javascript e folhas de estilo CSS, guardando-os como fiecheiros estáticos. Isso torna o sítio mais rápido nos navegadores.',
-	'texte_compresseur_page' => 'SPIP pode comprimir automaticamente todas as páginas que envia. Essa opção reduz a largura de banda, tornando o sítio mais rápido (ideal para ligações lentas), mas requer mais recursos do servidor.',
-	'titre_compacter_script_css' => 'Compressão dos scripts e CSS',
-	'titre_compresser_flux_http' => 'Compressão de HTML'
+	'titre_compacter_script_css' => 'Compressão dos scripts e CSS'
 );
 
 ?>
